<?php
/**
 * Plugin Name: ingenidev, CashOnDelivery Shield
 * Plugin URI: https://ingenidev.com/cod-shield-wordpress-plugin/
 * Author: ingenidev
 * Author URI: https://ingenidev.com
 * Description: This plugin provides customization options for the default WooCommerce Cash On delivery payment method
 * Version: 1.0.0
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */

defined('ABSPATH') or die('Direct access not permitted');

add_filter('woocommerce_available_payment_gateways', 'disable_cod_for_unknown_customer_phones');

function ingenidev_cods_disable_cod_for_unknown_customer_phones($available_gateways) {
 if (!is_user_logged_in() && isset($available_gateways['cod'])) {
 unset($available_gateways['cod']);
 }

 return $available_gateways;
}
register_activation_hook(__FILE__, 'ingenidev_cods_activate');

function ingenidev_cods_activate()
{
    add_option('ingenidev_cods_welcome_displayed', false);
}

add_action('admin_notices', 'ingenidev_cods_welcome_message');

function ingenidev_cods_welcome_message()
{
    if (!get_option('ingenidev_cods_welcome_displayed') && is_admin() && current_user_can('manage_options')) {
        ?>
        <div class="notice notice-success is-dismissible" id="ingenidev-welcome-notice">
            <img src="https://ingenidev.com/downloads/ingenidev/ingenidev-cash-on-delivery-shield/cods-icon.png" style="width: 32px; height: 32px; margin-right: 10px;" alt="" />
            <p><?php _e('Welcome! Thank you for installing ingenidev Cash on Delivery Shield', 'ingenidev_cods'); ?></p>
            <button type="button" class="notice-dismiss" id="ingenidev-dismiss-notice"></button>
        </div>
        <script type="text/javascript">
            jQuery(document).ready(function($) {
                $('body').on('click', '#ingenidev-dismiss-notice', function() {
                    $.ajax({
                        type: 'POST',
                        url: ajaxurl,
                        data: {
                            action: 'ingenidev_cods_dismiss_welcome_notice'
                        },
                        success: function() {
                            $('#ingenidev-welcome-notice').hide();
                        }
                    });
                });
            });
        </script>
        <?php
        update_option('ingenidev_cods_welcome_displayed', true);
    }
}

add_action('wp_ajax_ingenidev_cods_dismiss_welcome_notice', 'ingenidev_cods_dismiss_welcome_notice');

function ingenidev_cods_dismiss_welcome_notice()
{
    update_option('ingenidev_cods_welcome_displayed', true);
    wp_die();
}

add_action('wp_dashboard_setup', 'ingenidev_cods_custom_dashboard_widgets');

function ingenidev_cods_custom_dashboard_widgets()
{
    global $wp_meta_boxes;
    wp_add_dashboard_widget('ingenidev-cods-welcome-widget', 'ingenidev, Cash on Delivery Shield', 'ingenidev_cods_custom_dashboard_help');
}

function ingenidev_cods_custom_dashboard_help()
{
    ?>
    <p>Thank you for installing our Plugin. Should you encounter any issues, please do not hesitate to contact us.</p>
    <?php
}

class ingenidev_cods_UpdateChecker
{
    public $plugin_slug;
    public $version;
    public $cache_key;
    public $cache_allowed;

    public function __construct()
    {
        $this->plugin_slug = plugin_basename(__DIR__);
        $this->version = '1.0.0';
        $this->cache_key = 'ingenidev_cods_UpdateChecker_custom_upd';
        $this->cache_allowed = false;

        add_filter('plugins_api', array($this, 'info'), 20, 3);
        add_filter('site_transient_update_plugins', array($this, 'update'));
        add_action('upgrader_process_complete', array($this, 'purge'), 10, 2);
    }

    public function request()
    {
        $remote = get_transient($this->cache_key);

        if (false === $remote || !$this->cache_allowed) {
            $remote = wp_remote_get(
                'https://ingenidev.com/downloads/ingenidev/ingenidev-cash-on-delivery-shield/info.json',
                array(
                    'timeout' => 10,
                    'headers' => array(
                        'Accept' => 'application/json'
                    )
                )
            );

            if (
                is_wp_error($remote)
                || 200 !== wp_remote_retrieve_response_code($remote)
                || empty(wp_remote_retrieve_body($remote))
            ) {
                return false;
            }

            set_transient($this->cache_key, $remote, DAY_IN_SECONDS);
        }

        $remote = json_decode(wp_remote_retrieve_body($remote));

        return $remote;
    }

    function info($res, $action, $args)
    {
        if ('plugin_information' !== $action) {
            return $res;
        }

        if ($this->plugin_slug !== $args->slug) {
            return $res;
        }

        $remote = $this->request();

        if (!$remote) {
            return $res;
        }

        $res = new stdClass();

        $res->name = $remote->name;
        $res->slug = $remote->slug;
        $res->version = $remote->version;
        $res->tested = $remote->tested;
        $res->requires = $remote->requires;
        $res->author = $remote->author;
        $res->author_profile = $remote->author_profile;
        $res->download_link = $remote->download_url;
        $res->trunk = $remote->download_url;
        $res->requires_php = $remote->requires_php;
        $res->last_updated = $remote->last_updated;

        $res->sections = array(
            'description' => $remote->sections->description,
            'installation' => $remote->sections->installation,
            'changelog' => $remote->sections->changelog
        );

        if (!empty($remote->banners)) {
            $res->banners = array(
                'low' => $remote->banners->low,
                'high' => $remote->banners->high
            );
        }

        return $res;
    }

    public function update($transient)
    {
        if (empty($transient->checked)) {
            return $transient;
        }

        $remote = $this->request();

        if (
            $remote
            && version_compare($this->version, $remote->version, '<')
            && version_compare($remote->requires, get_bloginfo('version'), '<=')
            && version_compare($remote->requires_php, PHP_VERSION, '<')
        ) {
            $res = new stdClass();
            $res->slug = $this->plugin_slug;
            $res->plugin = plugin_basename(__FILE__);
            $res->new_version = $remote->version;
            $res->tested = $remote->tested;
            $res->package = $remote->download_url;

            $transient->response[$res->plugin] = $res;
        }

        return $transient;
    }

    public function purge($upgrader, $options)
    {
        if (
            $this->cache_allowed
            && 'update' === $options['action']
            && 'plugin' === $options['type']
        ) {
            delete_transient($this->cache_key);
        }
    }
}

new ingenidev_cods_UpdateChecker();

register_uninstall_hook(__FILE__, 'ingenidev_cods_uninstall');

function ingenidev_cods_uninstall()
{
    delete_option('ingenidev_cods_welcome_displayed');
}
?>
